==> ulyxex.0.0.4.with-tinyMce.zip: pages/code/admin_article_add.php <==
<?php
class ArticleAdd extends Admin {
	public function add_article() {
		$h = New Html();
		$hide = (isset($_POST['hide']))?1:0;
		$now = time();
		$date = date("Y-m-d H:i:s",$now);
		/* in case of no page created		*/
		$siteDat = $this->home_params();
		$pageId = isset($_POST['pageid'])?$h->num($_POST['pageid']):$siteDat['SANDBOXID'];
		$content = $h->safe($_POST['content']);
		$req = "INSERT INTO ".ARTICLES."  (SUBJECT,USERID,DATE,CONTENT,HIDE,PAGEID) VALUES (".
										"'".$h->safe($_POST['subject'])."',".$h->num($_POST['userid']).",'".
										$date."','".$content."',".
										$h->num($hide).",".$pageId.");";
		$req = $this->req($req);
		$result = $h->h3("article ".strip_tags($_POST['subject'])." created !");
		return $result;
	}
	public function add_article_form() {
		$h = New Html();
		$siteDat = $this->home_params();
		$content = $h->input("hidden","add",1);
		$content .= $h->input("hidden","userid",$_SESSION['userid']);
		$content .=  $h->p("hide ".$h->input("checkbox","hide","on"));
		$content .= ($_SESSION['level'] < 4)?  $h->p("choose page ".$this->SelectUserPages("pageid",$siteDat['PAGEID'])): $h->p("SandBox").$h->input("hidden","pageid",$siteDat['SANDBOXID']);
		$content .=  $h->p("subject (not displayed)").$h->p($h->input("content","subject","","size=".FIELDWIDTH));
		$content .=  $h->p("content").$h->p($h->textarea("","content",array(12,FIELDWIDTH)));
		$content .=  $h->p($h->input("submit","save","save"));
		$result = $h->form($content,"article","post","admin.php?action=add_article");
		return $result;
	}
}
?>

==> ulyxex.0.0.5.with-tinyMce.zip: pages/code/admin_article_add.php <==
<?php
class ArticleAdd extends Admin {
	public function add_article() {
		$h = New Html();
		$hide = (isset($_POST['hide']))?1:0;
		$now = time();
		$date = date("Y-m-d H:i:s",$now);
		if ($_POST['subject'] == "") $_POST['subject'] = "no subject";
		/* in case of page no exist		*/
		$siteDat = $this->home_params();
		$pageId = isset($_POST['pageid'])?$h->num($_POST['pageid']):$siteDat['SANDBOXID'];
		$content = $h->safe($_POST['content']);
		$query = "INSERT INTO ".ARTICLES."  (SUBJECT,USERID,DATE,CONTENT,HIDE,PAGEID) VALUES (".
										"'".$h->safe($_POST['subject'])."',".$h->num($_POST['userid']).",'".
										$date."','".$content."',".
										$h->num($hide).",".$pageId.");";
		$query = $this->q($query);
		$result = $h->h3("article ".strip_tags($_POST['subject'])." created !");
		return $result;
	}
	public function add_article_form() {
		$h = New Html();
		$siteDat = $this->home_params();
		$content = $h->input("hidden","add",1);
		$content .= $h->input("hidden","userid",$_SESSION['userid']);
		$content .=  $h->p("hide ".$h->input("checkbox","hide","on"));
		$content .= ($_SESSION['level'] < 4)?  $h->p("choose page ".$this->SelectUserPages("pageid",$siteDat['PAGEID'])): $h->p("SandBox").$h->input("hidden","pageid",$siteDat['SANDBOXID']);
		$content .=  $h->p("subject (not displayed only for admin)").$h->p($h->input("content","subject","","size=".FIELDWIDTH));
		$content .=  $h->p("content").$h->p($h->textarea("","content",array(12,FIELDWIDTH)));
		$content .=  $h->p($h->input("submit","save","save"));
		$result = $h->form($content,"article","post","admin.php?action=add_article");
		return $result;
	}
}
?>
